# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/entities/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/entities/v1/entities_v1.proto\x12\x1bstrmprivacy.api.entities.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1agoogle/type/datetime.proto\x1a\x17validate/validate.proto\"\xab\x05\n\x06Stream\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x0b\xe0\x41\x02\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12-\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\x18\xe8\x07\xd0\x01\x01R\x0b\x64\x65scription\x12/\n\x0e\x63onsent_levels\x18\x03 \x03(\x05\x42\x08\xfa\x42\x05\x92\x01\x02\x10\x32R\rconsentLevels\x12[\n\x12\x63onsent_level_type\x18\x04 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelTypeR\x10\x63onsentLevelType\x12\x1d\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x03\xe0\x41\x03R\x07\x65nabled\x12@\n\x06limits\x18\x06 \x01(\x0b\x32#.strmprivacy.api.entities.v1.LimitsB\x03\xe0\x41\x03R\x06limits\x12#\n\rlinked_stream\x18\x07 \x01(\tR\x0clinkedStream\x12$\n\x04tags\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\x10\x14\x18\x01\"\x04r\x02\x18\x64R\x04tags\x12O\n\x0b\x63redentials\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsB\x03\xe0\x41\x03R\x0b\x63redentials\x12N\n\rmasked_fields\x18\n \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\x12&\n\x0bkafka_topic\x18\x0b \x01(\tB\x05\x18\x01\xe0\x41\x03R\nkafkaTopic\x12(\n\tpolicy_id\x18\x0c \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x08policyId\"\xaa\x01\n\x0e\x45xtendedStream\x12@\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x03\xe0\x41\x03R\x06stream\x12\x19\n\x05topic\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05topic\x12\x17\n\x04uuid\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x04uuid\x12\"\n\nkey_stream\x18\x04 \x01(\x08\x42\x03\xe0\x41\x03R\tkeyStream\"\xc2\x01\n\x13\x45xtendedStreamGroup\x12U\n\rsource_stream\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamB\x03\xe0\x41\x03R\x0csourceStream\x12T\n\x0f\x64\x65rived_streams\x18\x02 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamR\x0e\x64\x65rivedStreams\"\x8f\x03\n\x0cMaskedFields\x12\x1b\n\thash_type\x18\x01 \x01(\tR\x08hashType\x12\x35\n\x04seed\x18\x02 \x01(\tB!\xfa\x42\x1er\x1c\x18\xe8\x07\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$\xd0\x01\x01R\x04seed\x12\x63\n\x0e\x66ield_patterns\x18\x03 \x03(\x0b\x32<.strmprivacy.api.entities.v1.MaskedFields.FieldPatternsEntryR\rfieldPatterns\x1aw\n\x12\x46ieldPatternsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12K\n\x05value\x18\x02 \x01(\x0b\x32\x35.strmprivacy.api.entities.v1.MaskedFields.PatternListR\x05value:\x02\x38\x01\x1aM\n\x0bPatternList\x12>\n\x0e\x66ield_patterns\x18\x01 \x03(\tB\x17\xfa\x42\x14\x92\x01\x11\x18\x01\"\rr\x0b\xba\x01\x08strmMetaR\rfieldPatterns\"R\n\x06Limits\x12\"\n\nevent_rate\x18\x01 \x01(\x03\x42\x03\xe0\x41\x03R\teventRate\x12$\n\x0b\x65vent_count\x18\x02 \x01(\x03\x42\x03\xe0\x41\x03R\neventCount\"\x92\x01\n\tKeyStream\x12@\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x03R\x03ref\x12\x1d\n\x06status\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x03R\x06status\x12$\n\x0bkafka_topic\x18\x03 \x01(\tB\x03\xe0\x41\x03R\nkafkaTopic\"\x9a\x01\n\tStreamRef\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x36\n\x04name\x18\x02 \x01(\tB\"\xfa\x42\x1fr\x1d\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$\xd0\x01\x01R\x04name\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x9d\x01\n\x0cKeyStreamRef\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x36\n\x04name\x18\x02 \x01(\tB\"\xfa\x42\x1fr\x1d\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$\xd0\x01\x01R\x04name\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xa1\x01\n\x0b\x43redentials\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\tbillingId\x12 \n\tclient_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12\"\n\nproject_id\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xdf\x01\n\x04Sink\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12G\n\tsink_type\x18\x02 \x01(\x0e\x32%.strmprivacy.api.entities.v1.SinkTypeB\x03\xe0\x41\x02R\x08sinkType\x12\x43\n\x06\x62ucket\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.BucketConfigH\x00R\x06\x62ucket:\x02\x18\x01\x42\x08\n\x06\x63onfig\"J\n\x07SinkRef\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name:\x02\x18\x01\"\x83\x01\n\x0c\x42ucketConfig\x12$\n\x0b\x62ucket_name\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nbucketName\x12%\n\x0b\x63redentials\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0b\x63redentials\x12&\n\x0f\x61ssume_role_arn\x18\x06 \x01(\tR\rassumeRoleArn\"\xcd\x04\n\rDataConnector\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12O\n\ts3_bucket\x18\x02 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.AwsS3BucketLocationH\x00R\x08s3Bucket\x12~\n\x1bgoogle_cloud_storage_bucket\x18\x03 \x01(\x0b\x32=.strmprivacy.api.entities.v1.GoogleCloudStorageBucketLocationH\x00R\x18googleCloudStorageBucket\x12\x81\x01\n\x1c\x61zure_blob_storage_container\x18\x04 \x01(\x0b\x32>.strmprivacy.api.entities.v1.AzureBlobStorageContainerLocationH\x00R\x19\x61zureBlobStorageContainer\x12\x1f\n\x04uuid\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x04uuid\x12j\n\x12\x64\x65pendent_entities\x18\x06 \x01(\x0b\x32;.strmprivacy.api.entities.v1.DataConnectorDependentEntitiesR\x11\x64\x65pendentEntitiesB\x0f\n\x08location\x12\x03\xf8\x42\x01\"\x9e\x01\n\x10\x44\x61taConnectorRef\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xb3\x02\n\x1e\x44\x61taConnectorDependentEntities\x12S\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\x12\x44\n\nbatch_jobs\x18\x02 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobR\tbatchJobs\x12v\n\x1cmicro_aggregation_batch_jobs\x18\x03 \x03(\x0b\x32\x35.strmprivacy.api.entities.v1.MicroAggregationBatchJobR\x19microAggregationBatchJobs\"\x9e\x01\n\x13\x41wsS3BucketLocation\x12(\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nbucketName\x12)\n\x0b\x63redentials\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x63redentials\x12\x32\n\x0f\x61ssume_role_arn\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xd0\x01\x01R\rassumeRoleArn\"w\n GoogleCloudStorageBucketLocation\x12(\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nbucketName\x12)\n\x0b\x63redentials\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x63redentials\"\x8a\x02\n!AzureBlobStorageContainerLocation\x12\x37\n\x13storage_account_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x11storageAccountUri\x12.\n\x0e\x63ontainer_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\rcontainerName\x12|\n\x18\x63lient_secret_credential\x18\x03 \x01(\x0b\x32\x38.strmprivacy.api.entities.v1.AzureClientSecretCredentialB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x16\x63lientSecretCredential\"\x97\x01\n\x1b\x41zureClientSecretCredential\x12$\n\ttenant_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08tenantId\x12$\n\tclient_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63lientId\x12,\n\rclient_secret\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0c\x63lientSecret\"X\n\x08\x44\x61taType\x12:\n\x03\x63sv\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.CsvConfigH\x00R\x03\x63svB\x10\n\tdata_type\x12\x03\xf8\x42\x01\"%\n\tCsvConfig\x12\x18\n\x07\x63harset\x18\x01 \x01(\tR\x07\x63harset\"\x8a\x05\n\rBatchExporter\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12G\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefH\x00R\tstreamRef\x12Q\n\x0ekey_stream_ref\x18\x03 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefH\x00R\x0ckeyStreamRef\x12I\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x12\xe0\x41\x02\xfa\x42\x0c\xaa\x01\t\"\x03\x08\x90\x1c\x32\x02\x08\x1eR\x08interval\x12*\n\tsink_name\x18\x05 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\x08sinkName\x12[\n\x0bpath_prefix\x18\x06 \x01(\tB:\xfa\x42\x37r5\x18\x84\x07\x32\t^.+[^\\/]$Z\x01.Z\x02..\xba\x01\x1a.well-known/acme-challenge\xd0\x01\x01R\npathPrefix\x12\x36\n\x17include_existing_events\x18\x07 \x01(\x08R\x15includeExistingEvents\x12\x65\n\x12\x64\x61ta_connector_ref\x18\x08 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x10\x64\x61taConnectorRefB\x1f\n\x18stream_or_key_stream_ref\x12\x03\xf8\x42\x01\"\x98\x01\n\x15\x45xtendedBatchExporter\x12\x17\n\x04uuid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04uuid\x12\x19\n\x05topic\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05topic\x12K\n\x08\x65xporter\x18\x03 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterB\x03\xe0\x41\x03R\x08\x65xporter\"\xa1\x01\n\x10\x42\x61tchExporterRef\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x36\n\x04name\x18\x02 \x01(\tB\"\xfa\x42\x1fr\x1d\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$\xd0\x01\x01R\x04name\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xfa\x01\n\x0cKafkaCluster\x12\x43\n\x03ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02R\x03ref\x12\x30\n\x11\x62ootstrap_servers\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x10\x62ootstrapServers\x12V\n\x0e\x61uth_mechanism\x18\x03 \x01(\x0e\x32*.strmprivacy.api.entities.v1.AuthMechanismB\x03\xe0\x41\x02R\rauthMechanism\x12\x1b\n\ttoken_uri\x18\x04 \x01(\tR\x08tokenUri\"\x91\x01\n\x0fKafkaClusterRef\x12\x1d\n\nbilling_id\x18\x01 \x01(\tR\tbillingId\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\xb3\x02\n\rKafkaExporter\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12O\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tstreamRef\x12H\n\x06target\x18\x03 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.KafkaExporterTargetR\x06target\x12<\n\x05users\x18\x04 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserR\x05users\"\x92\x01\n\x10KafkaExporterRef\x12\x1d\n\nbilling_id\x18\x01 \x01(\tR\tbillingId\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12*\n\nproject_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\x84\x02\n\x13KafkaExporterTarget\x12W\n\x0b\x63luster_ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nclusterRef\x12\x31\n\x05topic\x18\x02 \x01(\tB\x1b\xfa\x42\x18r\x16\x18\xf9\x01\x32\x11^[a-zA-Z0-9._-]+$R\x05topic\x12(\n\tclient_id\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x08\x63lientId\x12\x37\n\rclient_secret\x18\x04 \x01(\tB\x12\xfa\x42\x0fr\r2\x08^[ -~]+$\xd0\x01\x01R\x0c\x63lientSecret\"\xc2\x02\n\tKafkaUser\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x33\n\x13kafka_exporter_name\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x11kafkaExporterName\x12\x19\n\x05topic\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x05topic\x12 \n\tclient_id\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12R\n\x0b\x63luster_ref\x18\x07 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x03R\nclusterRef\"n\n\x0cKafkaUserRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"6\n\rConsentLevels\x12%\n\x0e\x63onsent_levels\x18\x01 \x03(\x05R\rconsentLevels\"\x9b\x01\n\x13\x43onsentLevelMapping\x12O\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\"\x8d\x01\n\x16\x43onsentLevelMappingRef\x12+\n\nbilling_id\x18\x01 \x01(\tB\x0c\x18\x01\xfa\x42\x07r\x05\x18\x00\xd0\x01\x01R\tbillingId\x12\x1d\n\x05level\x18\x02 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\x05level\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xfa\x02\n\x06Policy\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12*\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xe8\x07R\x0b\x64\x65scription\x12-\n\rlegal_grounds\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xe8\x07R\x0clegalGrounds\x12.\n\x0eretention_days\x18\x05 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x01R\rretentionDays\x12?\n\x05state\x18\x06 \x01(\x0e\x32).strmprivacy.api.entities.v1.Policy.StateR\x05state\"U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bSTATE_DRAFT\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x12\n\x0eSTATE_ARCHIVED\x10\x03\"\xb6\x01\n\x12WindowedEventCount\x12>\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstartTime\x12:\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x07\x65ndTime\x12$\n\x0b\x65vent_count\x18\x03 \x01(\x03\x42\x03\xe0\x41\x03R\neventCount\"\xaf\x01\n\tSchemaRef\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12M\n\x0bschema_type\x18\x04 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x03R\nschemaType\"\xdb\x06\n\x06Schema\x12\x42\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x44\n\x05state\x18\x02 \x01(\x0e\x32).strmprivacy.api.entities.v1.Schema.StateB\x03\xe0\x41\x03R\x05state\x12\x1b\n\tis_public\x18\x03 \x01(\x08R\x08isPublic\x12\x1e\n\ndefinition\x18\x04 \x01(\tR\ndefinition\x12%\n\x0b\x66ingerprint\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x0b\x66ingerprint\x12G\n\x08metadata\x18\x06 \x01(\x0b\x32+.strmprivacy.api.entities.v1.SchemaMetadataR\x08metadata\x12_\n\rsimple_schema\x18\x07 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionR\x0csimpleSchema\x12\x13\n\x02id\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x02id\x1a\xbf\x02\n\x16SimpleSchemaDefinition\x12$\n\x04name\x18\x01 \x01(\tB\x10\xfa\x42\rr\x0b\x32\t^[^\\pC]+$R\x04name\x12]\n\tnamespace\x18\x02 \x01(\tB?\xfa\x42<r:25^([a-zA-Z_][a-zA-Z0-9_]*)(\\.[a-zA-Z_][a-zA-Z0-9_]*)*$\xd0\x01\x01R\tnamespace\x12\x1a\n\x03\x64oc\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\x18\x88\'R\x03\x64oc\x12\x43\n\x05nodes\x18\x04 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNodeR\x05nodes\x12?\n\tavro_name\x18\x05 \x01(\tB\"\xfa\x42\x1fr\x1d\x32\x18^[a-zA-Z_][a-zA-Z0-9_]*$\xd0\x01\x01R\x08\x61vroName\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\xe3\x02\n\x10SimpleSchemaNode\x12O\n\x04type\x18\x01 \x01(\x0e\x32\x31.strmprivacy.api.entities.v1.SimpleSchemaNodeTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x04type\x12$\n\x04name\x18\x02 \x01(\tB\x10\xfa\x42\rr\x0b\x32\t^[^\\pC]+$R\x04name\x12?\n\tavro_name\x18\x07 \x01(\tB\"\xfa\x42\x1fr\x1d\x32\x18^[a-zA-Z_][a-zA-Z0-9_]*$\xd0\x01\x01R\x08\x61vroName\x12\x1a\n\x08repeated\x18\x03 \x01(\x08R\x08repeated\x12\x1a\n\x08required\x18\x04 \x01(\x08R\x08required\x12\x43\n\x05nodes\x18\x05 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNodeR\x05nodes\x12\x1a\n\x03\x64oc\x18\x06 \x01(\tB\x08\xfa\x42\x05r\x03\x18\x88\'R\x03\x64oc\"\xd5\x02\n\x0eSchemaMetadata\x12-\n\x05title\x18\x01 \x01(\tB\x17\xfa\x42\x14r\x12\x10\x04\x18\x64\x32\t^[^\\pC]+$\xd0\x01\x01R\x05title\x12*\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\x18\x88\'R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x30\n\x08icon_uri\x18\x04 \x01(\tB\x15\xfa\x42\x12r\x10:\x08https://\xd0\x01\x01\x88\x01\x01R\x07iconUri\x12:\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelR\x06labels\x12\x18\n\x07\x64omains\x18\x06 \x03(\tR\x07\x64omains\x12\x1e\n\nindustries\x18\x07 \x03(\tR\nindustries\"\x9a\x01\n\x10\x45ventContractRef\x12\x1f\n\x06handle\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x04R\x06handle\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12\x30\n\x07version\x18\x03 \x01(\tB\x16\xfa\x42\x13r\x11\x32\x0f^\\d+\\.\\d+\\.\\d+$R\x07version\"\x82\x06\n\rEventContract\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x03ref\x12K\n\x05state\x18\x02 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.EventContract.StateB\x03\xe0\x41\x03R\x05state\x12J\n\nschema_ref\x18\x03 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\x1b\n\tis_public\x18\x04 \x01(\x08R\x08isPublic\x12 \n\tkey_field\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08keyField\x12X\n\npii_fields\x18\x06 \x03(\x0b\x32\x39.strmprivacy.api.entities.v1.EventContract.PiiFieldsEntryR\tpiiFields\x12I\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.ValidationR\x0bvalidations\x12N\n\x08metadata\x18\x08 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.EventContractMetadataR\x08metadata\x12\x0e\n\x02id\x18\t \x01(\tR\x02id\x12,\n\x12\x64\x61ta_subject_field\x18\n \x01(\tR\x10\x64\x61taSubjectField\x1a<\n\x0ePiiFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\xc0\x02\n\x15\x45ventContractMetadata\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x1e\n\x08icon_uri\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x07iconUri\x12?\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01R\nindustries\"8\n\x05Label\x12\x19\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"l\n\nValidation\x12\x1d\n\x05\x66ield\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x05\x66ield\x12 \n\x04type\x18\x02 \x01(\tB\x0c\xfa\x42\tr\x07R\x05regexR\x04type\x12\x1d\n\x05value\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x05value\"\xfe\x02\n\nStreamTree\x12@\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x03\xe0\x41\x02R\x06stream\x12\x45\n\nkey_stream\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamR\tkeyStream\x12=\n\x07\x64\x65rived\x18\x03 \x03(\x0b\x32#.strmprivacy.api.entities.v1.StreamR\x07\x64\x65rived\x12S\n\x0f\x62\x61tch_exporters\x18\x04 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\x12S\n\x0fkafka_exporters\x18\x05 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\x0ekafkaExporters\"\x9f\x01\n\x08SinkTree\x12:\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02R\x04sink\x12S\n\x0f\x62\x61tch_exporters\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters:\x02\x18\x01\"\xc8\x06\n\x08\x42\x61tchJob\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12G\n\x06states\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x03R\x06states\x12\\\n\x0bsource_data\x18\x03 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nsourceData\x12N\n\x07\x63onsent\x18\x04 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07\x63onsent\x12W\n\nencryption\x18\x05 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EncryptionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nencryption\x12\x65\n\x12\x65vent_contract_ref\x18\x06 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x10\x65ventContractRef\x12[\n\x0e\x65ncrypted_data\x18\x07 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EncryptedDataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rencryptedData\x12k\n\x14\x65ncryption_keys_data\x18\x08 \x01(\x0b\x32/.strmprivacy.api.entities.v1.EncryptionKeysDataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x12\x65ncryptionKeysData\x12K\n\x0c\x64\x65rived_data\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.DerivedDataR\x0b\x64\x65rivedData\x12(\n\tpolicy_id\x18\n \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x08policyId\"\xf0\x01\n\x0f\x42\x61tchJobWrapper\x12Y\n\x14\x65ncryption_batch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobH\x00R\x12\x65ncryptionBatchJob\x12v\n\x1bmicro_aggregation_batch_job\x18\x02 \x01(\x0b\x32\x35.strmprivacy.api.entities.v1.MicroAggregationBatchJobH\x00R\x18microAggregationBatchJobB\n\n\x03job\x12\x03\xf8\x42\x01\"\x9a\x01\n\x10\x45xtendedBatchJob\x12\x46\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x02\x18\x01R\x08\x62\x61tchJob\x12>\n\x03job\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperR\x03job\"y\n\x0b\x42\x61tchJobRef\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xb9\x01\n\rBatchJobState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12I\n\x05state\x18\x02 \x01(\x0e\x32..strmprivacy.api.entities.v1.BatchJobStateTypeB\x03\xe0\x41\x03R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x07message\"\xda\x02\n\x14\x44\x61taConnectorAndType\x12\x65\n\x12\x64\x61ta_connector_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x10\x64\x61taConnectorRef\x12[\n\x0bpath_prefix\x18\x02 \x01(\tB:\xfa\x42\x37r5\x18\x84\x07\x32\t^.+[^\\/]$Z\x01.Z\x02..\xba\x01\x1a.well-known/acme-challenge\xd0\x01\x01R\npathPrefix\x12\x30\n\tfile_name\x18\x03 \x01(\tB\x13\xfa\x42\x10r\x0e\x32\t^[^\\pC]+$\xd0\x01\x01R\x08\x66ileName\x12L\n\tdata_type\x18\x04 \x01(\x0b\x32%.strmprivacy.api.entities.v1.DataTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08\x64\x61taType\"\xbb\x01\n\rConsentConfig\x12\x39\n\x16\x64\x65\x66\x61ult_consent_levels\x18\x01 \x03(\x05\x42\x03\xe0\x41\x01R\x14\x64\x65\x66\x61ultConsentLevels\x12o\n\x17\x63onsent_level_extractor\x18\x02 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.ConsentLevelExtractorB\x03\xe0\x41\x01R\x15\x63onsentLevelExtractor\"\x89\x02\n\x15\x43onsentLevelExtractor\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12l\n\x0e\x66ield_patterns\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.entities.v1.ConsentLevelExtractor.FieldPatternsEntryR\rfieldPatterns\x1al\n\x12\x46ieldPatternsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12@\n\x05value\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentLevelsR\x05value:\x02\x38\x01\"\xa2\x01\n\x10\x45ncryptionConfig\x12\x61\n\x10timestamp_config\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.TimestampConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0ftimestampConfig\x12+\n\x12\x62\x61tch_job_group_id\x18\x02 \x01(\tR\x0f\x62\x61tchJobGroupId\"\xac\x01\n\x0fTimestampConfig\x12\x35\n\x05\x66ield\x18\x01 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x32\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x05\x66ield\x12\x1f\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x66ormat\x12\x41\n\x11\x64\x65\x66\x61ult_time_zone\x18\x03 \x01(\x0b\x32\x15.google.type.TimeZoneR\x0f\x64\x65\x66\x61ultTimeZone\"d\n\rEncryptedData\x12S\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06target\"i\n\x12\x45ncryptionKeysData\x12S\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06target\"\xb1\x02\n\x0b\x44\x65rivedData\x12N\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\x06target\x12%\n\x0e\x63onsent_levels\x18\x02 \x03(\x05R\rconsentLevels\x12[\n\x12\x63onsent_level_type\x18\x03 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelTypeR\x10\x63onsentLevelType\x12N\n\rmasked_fields\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\"\xb7\x04\n\x18MicroAggregationBatchJob\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12G\n\x06states\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x03R\x06states\x12\\\n\x0bsource_data\x18\x03 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nsourceData\x12\\\n\x0btarget_data\x18\x04 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\ntargetData\x12\x62\n\x11\x64\x61ta_contract_ref\x18\x05 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0f\x64\x61taContractRef\x12l\n\x12\x61ggregation_config\x18\x06 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.MicroAggregationConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x11\x61ggregationConfig\"\x80\x01\n\x16MicroAggregationConfig\x12\x37\n\x13minimum_k_anonymity\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x02R\x11minimumKAnonymity\x12-\n\x12\x61ggregation_fields\x18\x02 \x03(\tR\x11\x61ggregationFields\"\x9f\x01\n\x0f\x44\x61taContractRef\x12\"\n\x06handle\x18\x01 \x01(\tB\n\xe0\x41\x02\xfa\x42\x04r\x02\x10\x04R\x06handle\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12\x33\n\x07version\x18\x03 \x01(\tB\x19\xe0\x41\x02\xfa\x42\x13r\x11\x32\x0f^\\d+\\.\\d+\\.\\d+$R\x07version\"\x86\x07\n\x0c\x44\x61taContract\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12J\n\x05state\x18\x03 \x01(\x0e\x32/.strmprivacy.api.entities.v1.DataContract.StateB\x03\xe0\x41\x03R\x05state\x12\x1b\n\tis_public\x18\x04 \x01(\x08R\x08isPublic\x12$\n\tkey_field\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08keyField\x12[\n\npii_fields\x18\x06 \x03(\x0b\x32\x38.strmprivacy.api.entities.v1.DataContract.PiiFieldsEntryB\x02\x18\x01R\tpiiFields\x12I\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.ValidationR\x0bvalidations\x12M\n\x08metadata\x18\x08 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataContractMetadataR\x08metadata\x12\x45\n\x06schema\x18\t \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06schema\x12,\n\x12\x64\x61ta_subject_field\x18\n \x01(\tR\x10\x64\x61taSubjectField\x12\'\n\nproject_id\x18\x0b \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12Q\n\x0e\x66ield_metadata\x18\x0c \x03(\x0b\x32*.strmprivacy.api.entities.v1.FieldMetadataR\rfieldMetadata\x1a<\n\x0ePiiFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\r\n\tIN_REVIEW\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08\x41RCHIVED\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\xe1\x06\n\rFieldMetadata\x12\x1d\n\nfield_name\x18\x01 \x01(\tR\tfieldName\x12o\n\x14personal_data_config\x18\x02 \x01(\x0b\x32=.strmprivacy.api.entities.v1.FieldMetadata.PersonalDataConfigR\x12personalDataConfig\x12\x64\n\x15statistical_data_type\x18\x03 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.StatisticalDataTypeR\x13statisticalDataType\x12%\n\x0eordinal_values\x18\x04 \x03(\tR\rordinalValues\x12o\n\x14null_handling_config\x18\x05 \x01(\x0b\x32=.strmprivacy.api.entities.v1.FieldMetadata.NullHandlingConfigR\x12nullHandlingConfig\x1a\xc0\x01\n\x12PersonalDataConfig\x12\x1a\n\x06is_pii\x18\x01 \x01(\x08\x42\x03\xe0\x41\x02R\x05isPii\x12#\n\x0bis_quasi_id\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02R\tisQuasiId\x12#\n\rpurpose_level\x18\x03 \x01(\x05R\x0cpurposeLevel\x12\x44\n\x1fgdpr_special_personal_data_type\x18\x04 \x01(\tR\x1bgdprSpecialPersonalDataType\x1a\xfe\x01\n\x12NullHandlingConfig\x12g\n\x04type\x18\x01 \x01(\x0e\x32N.strmprivacy.api.entities.v1.FieldMetadata.NullHandlingConfig.NullHandlingTypeB\x03\xe0\x41\x02R\x04type\x12#\n\rdefault_value\x18\x02 \x01(\tR\x0c\x64\x65\x66\x61ultValue\"Z\n\x10NullHandlingType\x12\"\n\x1eNULL_HANDLING_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44ROP_RECORD\x10\x01\x12\x11\n\rDEFAULT_VALUE\x10\x02\"\xaa\x02\n\x14\x44\x61taContractMetadata\x12\x38\n\x05title\x18\x01 \x01(\tB\"\xfa\x42\x1fr\x1d\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$\xd0\x01\x01R\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12:\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelR\x06labels\x12\x18\n\x07\x64omains\x18\x06 \x03(\tR\x07\x64omains\x12\x1e\n\nindustries\x18\x07 \x03(\tR\nindustries\"\xbb\x02\n\x07Project\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\x33\n\x04name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x02\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x04name\x12*\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\x18\x88\'R\x0b\x64\x65scription\x12,\n\x0forganization_id\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0eorganizationId\x12\x45\n\x05state\x18\x05 \x01(\x0e\x32*.strmprivacy.api.entities.v1.Project.StateB\x03\xe0\x41\x03R\x05state\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bOPERATIONAL\x10\x01\x12\x14\n\x10PENDING_DELETION\x10\x02\"\xec\x01\n\x04User\x12 \n\x05\x65mail\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\xd0\x01\x01`\x01R\x05\x65mail\x12>\n\nfirst_name\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x02\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\tfirstName\x12<\n\tlast_name\x18\x03 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x02\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x08lastName\x12\x44\n\nuser_roles\x18\x04 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles\"\x82\x01\n\x0ePurposeMapping\x12\x1d\n\x05level\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\x05level\x12#\n\x07purpose\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x02\x18\x64R\x07purpose\x12,\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x02\xd0\x01\x01R\x0b\x64\x65scription*]\n\x08UserRole\x12\x19\n\x15USER_ROLE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\x11\n\rPROJECT_ADMIN\x10\x02\x12\x0c\n\x08\x41PPROVER\x10\x03\x12\n\n\x06MEMBER\x10\x04*\x8d\x01\n\x11\x42\x61tchJobStateType\x12$\n BATCH_JOB_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x12\n\x0e\x45RROR_STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08\x46INISHED\x10\x05\x12\t\n\x05\x45RROR\x10\x06*T\n\x10\x43onsentLevelType\x12\"\n\x1e\x43ONSENT_LEVEL_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCUMULATIVE\x10\x01\x12\x0c\n\x08GRANULAR\x10\x02*=\n\x08SinkType\x12\x19\n\x15SINK_TYPE_UNSPECIFIED\x10\x00\x12\x06\n\x02S3\x10\x01\x12\n\n\x06GCLOUD\x10\x02\x1a\x02\x18\x01*M\n\rAuthMechanism\x12\x1e\n\x1a\x41UTH_MECHANISM_UNSPECIFIED\x10\x00\x12\x0e\n\nSASL_PLAIN\x10\x01\x12\x0c\n\x08SASL_SSL\x10\x02*C\n\nSchemaType\x12\x1b\n\x17SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x41VRO\x10\x01\x12\x0e\n\nJSONSCHEMA\x10\x02*\x84\x01\n\x14SimpleSchemaNodeType\x12\'\n#SIMPLE_SCHEMA_NODE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07INTEGER\x10\x04\x12\x08\n\x04LONG\x10\x05\x12\x08\n\x04NODE\x10\n*_\n\x13\x46ilterPublicPrivate\x12%\n!FILTER_PUBLIC_PRIVATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bONLY_PUBLIC\x10\x01\x12\x10\n\x0cONLY_PRIVATE\x10\x02*e\n\x13StatisticalDataType\x12%\n!STATISTICAL_DATA_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07NOMINAL\x10\x01\x12\x0b\n\x07ORDINAL\x10\x02\x12\r\n\tNUMERICAL\x10\x03*\x92\x01\n\x10SubscriptionPlan\x12!\n\x1dSUBSCRIPTION_PLAN_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\x0c\n\x08\x42USINESS\x10\x02\x12\x0f\n\x0bSELF_HOSTED\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04\x12\x18\n\x14\x41WS_MARKETPLACE_BYOL\x10\x05\x42i\n\x1eio.strmprivacy.api.entities.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entitiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.entities.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.entities.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entities'
  _SINKTYPE._options = None
  _SINKTYPE._serialized_options = b'\030\001'
  _STREAM.fields_by_name['ref']._options = None
  _STREAM.fields_by_name['ref']._serialized_options = b'\340A\002\372B\005\212\001\002\020\001'
  _STREAM.fields_by_name['description']._options = None
  _STREAM.fields_by_name['description']._serialized_options = b'\372B\010r\006\030\350\007\320\001\001'
  _STREAM.fields_by_name['consent_levels']._options = None
  _STREAM.fields_by_name['consent_levels']._serialized_options = b'\372B\005\222\001\002\0202'
  _STREAM.fields_by_name['enabled']._options = None
  _STREAM.fields_by_name['enabled']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['limits']._options = None
  _STREAM.fields_by_name['limits']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['tags']._options = None
  _STREAM.fields_by_name['tags']._serialized_options = b'\372B\r\222\001\n\020\024\030\001\"\004r\002\030d'
  _STREAM.fields_by_name['credentials']._options = None
  _STREAM.fields_by_name['credentials']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['kafka_topic']._options = None
  _STREAM.fields_by_name['kafka_topic']._serialized_options = b'\030\001\340A\003'
  _STREAM.fields_by_name['policy_id']._options = None
  _STREAM.fields_by_name['policy_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _EXTENDEDSTREAM.fields_by_name['stream']._options = None
  _EXTENDEDSTREAM.fields_by_name['stream']._serialized_options = b'\340A\003'
  _EXTENDEDSTREAM.fields_by_name['topic']._options = None
  _EXTENDEDSTREAM.fields_by_name['topic']._serialized_options = b'\340A\003'
  _EXTENDEDSTREAM.fields_by_name['uuid']._options = None
  _EXTENDEDSTREAM.fields_by_name['uuid']._serialized_options = b'\340A\003'
  _EXTENDEDSTREAM.fields_by_name['key_stream']._options = None
  _EXTENDEDSTREAM.fields_by_name['key_stream']._serialized_options = b'\340A\003'
  _EXTENDEDSTREAMGROUP.fields_by_name['source_stream']._options = None
  _EXTENDEDSTREAMGROUP.fields_by_name['source_stream']._serialized_options = b'\340A\003'
  _MASKEDFIELDS_FIELDPATTERNSENTRY._options = None
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _MASKEDFIELDS_PATTERNLIST.fields_by_name['field_patterns']._options = None
  _MASKEDFIELDS_PATTERNLIST.fields_by_name['field_patterns']._serialized_options = b'\372B\024\222\001\021\030\001\"\rr\013\272\001\010strmMeta'
  _MASKEDFIELDS.fields_by_name['seed']._options = None
  _MASKEDFIELDS.fields_by_name['seed']._serialized_options = b'\372B\036r\034\030\350\0072\024^[\\pL\\pN\\pS\\pM\\pP]+$\320\001\001'
  _LIMITS.fields_by_name['event_rate']._options = None
  _LIMITS.fields_by_name['event_rate']._serialized_options = b'\340A\003'
  _LIMITS.fields_by_name['event_count']._options = None
  _LIMITS.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['ref']._options = None
  _KEYSTREAM.fields_by_name['ref']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['status']._options = None
  _KEYSTREAM.fields_by_name['status']._serialized_options = b'\030\001\340A\003'
  _KEYSTREAM.fields_by_name['kafka_topic']._options = None
  _KEYSTREAM.fields_by_name['kafka_topic']._serialized_options = b'\340A\003'
  _STREAMREF.fields_by_name['billing_id']._options = None
  _STREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _STREAMREF.fields_by_name['name']._options = None
  _STREAMREF.fields_by_name['name']._serialized_options = b'\372B\037r\035\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$\320\001\001'
  _STREAMREF.fields_by_name['project_id']._options = None
  _STREAMREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _KEYSTREAMREF.fields_by_name['billing_id']._options = None
  _KEYSTREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _KEYSTREAMREF.fields_by_name['name']._options = None
  _KEYSTREAMREF.fields_by_name['name']._serialized_options = b'\372B\037r\035\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$\320\001\001'
  _KEYSTREAMREF.fields_by_name['project_id']._options = None
  _KEYSTREAMREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _CREDENTIALS.fields_by_name['billing_id']._options = None
  _CREDENTIALS.fields_by_name['billing_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['client_id']._options = None
  _CREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['client_secret']._options = None
  _CREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['project_id']._options = None
  _CREDENTIALS.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _SINK.fields_by_name['ref']._options = None
  _SINK.fields_by_name['ref']._serialized_options = b'\340A\002'
  _SINK.fields_by_name['sink_type']._options = None
  _SINK.fields_by_name['sink_type']._serialized_options = b'\340A\002'
  _SINK._options = None
  _SINK._serialized_options = b'\030\001'
  _SINKREF.fields_by_name['billing_id']._options = None
  _SINKREF.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _SINKREF.fields_by_name['name']._options = None
  _SINKREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SINKREF._options = None
  _SINKREF._serialized_options = b'\030\001'
  _BUCKETCONFIG.fields_by_name['bucket_name']._options = None
  _BUCKETCONFIG.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _BUCKETCONFIG.fields_by_name['credentials']._options = None
  _BUCKETCONFIG.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _DATACONNECTOR.oneofs_by_name['location']._options = None
  _DATACONNECTOR.oneofs_by_name['location']._serialized_options = b'\370B\001'
  _DATACONNECTOR.fields_by_name['ref']._options = None
  _DATACONNECTOR.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATACONNECTOR.fields_by_name['uuid']._options = None
  _DATACONNECTOR.fields_by_name['uuid']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DATACONNECTORREF.fields_by_name['billing_id']._options = None
  _DATACONNECTORREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DATACONNECTORREF.fields_by_name['name']._options = None
  _DATACONNECTORREF.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _DATACONNECTORREF.fields_by_name['project_id']._options = None
  _DATACONNECTORREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\372B\004r\002\020\001'
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\372B\004r\002\020\001'
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._serialized_options = b'\372B\007r\005\020\001\320\001\001'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\372B\004r\002\020\001'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\372B\004r\002\020\001'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._serialized_options = b'\372B\004r\002\020\001'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._serialized_options = b'\372B\004r\002\020\001'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._serialized_options = b'\372B\004r\002\020\001'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._serialized_options = b'\372B\004r\002\020\001'
  _DATATYPE.oneofs_by_name['data_type']._options = None
  _DATATYPE.oneofs_by_name['data_type']._serialized_options = b'\370B\001'
  _BATCHEXPORTER.oneofs_by_name['stream_or_key_stream_ref']._options = None
  _BATCHEXPORTER.oneofs_by_name['stream_or_key_stream_ref']._serialized_options = b'\370B\001'
  _BATCHEXPORTER.fields_by_name['ref']._options = None
  _BATCHEXPORTER.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHEXPORTER.fields_by_name['interval']._options = None
  _BATCHEXPORTER.fields_by_name['interval']._serialized_options = b'\340A\002\372B\014\252\001\t\"\003\010\220\0342\002\010\036'
  _BATCHEXPORTER.fields_by_name['sink_name']._options = None
  _BATCHEXPORTER.fields_by_name['sink_name']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _BATCHEXPORTER.fields_by_name['path_prefix']._options = None
  _BATCHEXPORTER.fields_by_name['path_prefix']._serialized_options = b'\372B7r5\030\204\0072\t^.+[^\\/]$Z\001.Z\002..\272\001\032.well-known/acme-challenge\320\001\001'
  _BATCHEXPORTER.fields_by_name['data_connector_ref']._options = None
  _BATCHEXPORTER.fields_by_name['data_connector_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENDEDBATCHEXPORTER.fields_by_name['uuid']._options = None
  _EXTENDEDBATCHEXPORTER.fields_by_name['uuid']._serialized_options = b'\340A\003'
  _EXTENDEDBATCHEXPORTER.fields_by_name['topic']._options = None
  _EXTENDEDBATCHEXPORTER.fields_by_name['topic']._serialized_options = b'\340A\003'
  _EXTENDEDBATCHEXPORTER.fields_by_name['exporter']._options = None
  _EXTENDEDBATCHEXPORTER.fields_by_name['exporter']._serialized_options = b'\340A\003'
  _BATCHEXPORTERREF.fields_by_name['billing_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _BATCHEXPORTERREF.fields_by_name['name']._options = None
  _BATCHEXPORTERREF.fields_by_name['name']._serialized_options = b'\372B\037r\035\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$\320\001\001'
  _BATCHEXPORTERREF.fields_by_name['project_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _KAFKACLUSTER.fields_by_name['ref']._options = None
  _KAFKACLUSTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._options = None
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._options = None
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._serialized_options = b'\340A\002'
  _KAFKACLUSTERREF.fields_by_name['name']._options = None
  _KAFKACLUSTERREF.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _KAFKACLUSTERREF.fields_by_name['project_id']._options = None
  _KAFKACLUSTERREF.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _KAFKAEXPORTER.fields_by_name['ref']._options = None
  _KAFKAEXPORTER.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _KAFKAEXPORTER.fields_by_name['stream_ref']._options = None
  _KAFKAEXPORTER.fields_by_name['stream_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _KAFKAEXPORTERREF.fields_by_name['name']._options = None
  _KAFKAEXPORTERREF.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _KAFKAEXPORTERREF.fields_by_name['project_id']._options = None
  _KAFKAEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._serialized_options = b'\372B\030r\026\030\371\0012\021^[a-zA-Z0-9._-]+$'
  _KAFKAEXPORTERTARGET.fields_by_name['client_id']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['client_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _KAFKAEXPORTERTARGET.fields_by_name['client_secret']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['client_secret']._serialized_options = b'\372B\017r\r2\010^[ -~]+$\320\001\001'
  _KAFKAUSER.fields_by_name['ref']._options = None
  _KAFKAUSER.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._options = None
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['topic']._options = None
  _KAFKAUSER.fields_by_name['topic']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_id']._options = None
  _KAFKAUSER.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_secret']._options = None
  _KAFKAUSER.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['cluster_ref']._options = None
  _KAFKAUSER.fields_by_name['cluster_ref']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['billing_id']._options = None
  _KAFKAUSERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKAUSERREF.fields_by_name['name']._options = None
  _KAFKAUSERREF.fields_by_name['name']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['project_id']._options = None
  _KAFKAUSERREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _CONSENTLEVELMAPPING.fields_by_name['ref']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CONSENTLEVELMAPPING.fields_by_name['name']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\007r\005\030\000\320\001\001'
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._serialized_options = b'\372B\004\032\002(\000'
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _POLICY.fields_by_name['id']._options = None
  _POLICY.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _POLICY.fields_by_name['name']._options = None
  _POLICY.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _POLICY.fields_by_name['description']._options = None
  _POLICY.fields_by_name['description']._serialized_options = b'\372B\005r\003\030\350\007'
  _POLICY.fields_by_name['legal_grounds']._options = None
  _POLICY.fields_by_name['legal_grounds']._serialized_options = b'\372B\005r\003\030\350\007'
  _POLICY.fields_by_name['retention_days']._options = None
  _POLICY.fields_by_name['retention_days']._serialized_options = b'\372B\004\032\002(\001'
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _SCHEMAREF.fields_by_name['handle']._options = None
  _SCHEMAREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['name']._options = None
  _SCHEMAREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['version']._options = None
  _SCHEMAREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['schema_type']._options = None
  _SCHEMAREF.fields_by_name['schema_type']._serialized_options = b'\340A\003'
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['name']._options = None
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['name']._serialized_options = b'\372B\rr\0132\t^[^\\pC]+$'
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['namespace']._options = None
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['namespace']._serialized_options = b'\372B<r:25^([a-zA-Z_][a-zA-Z0-9_]*)(\\.[a-zA-Z_][a-zA-Z0-9_]*)*$\320\001\001'
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['doc']._options = None
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['doc']._serialized_options = b'\372B\005r\003\030\210\''
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['avro_name']._options = None
  _SCHEMA_SIMPLESCHEMADEFINITION.fields_by_name['avro_name']._serialized_options = b'\372B\037r\0352\030^[a-zA-Z_][a-zA-Z0-9_]*$\320\001\001'
  _SCHEMA.fields_by_name['ref']._options = None
  _SCHEMA.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SCHEMA.fields_by_name['state']._options = None
  _SCHEMA.fields_by_name['state']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['fingerprint']._options = None
  _SCHEMA.fields_by_name['fingerprint']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['id']._options = None
  _SCHEMA.fields_by_name['id']._serialized_options = b'\340A\003'
  _SIMPLESCHEMANODE.fields_by_name['type']._options = None
  _SIMPLESCHEMANODE.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002 \000'
  _SIMPLESCHEMANODE.fields_by_name['name']._options = None
  _SIMPLESCHEMANODE.fields_by_name['name']._serialized_options = b'\372B\rr\0132\t^[^\\pC]+$'
  _SIMPLESCHEMANODE.fields_by_name['avro_name']._options = None
  _SIMPLESCHEMANODE.fields_by_name['avro_name']._serialized_options = b'\372B\037r\0352\030^[a-zA-Z_][a-zA-Z0-9_]*$\320\001\001'
  _SIMPLESCHEMANODE.fields_by_name['doc']._options = None
  _SIMPLESCHEMANODE.fields_by_name['doc']._serialized_options = b'\372B\005r\003\030\210\''
  _SCHEMAMETADATA.fields_by_name['title']._options = None
  _SCHEMAMETADATA.fields_by_name['title']._serialized_options = b'\372B\024r\022\020\004\030d2\t^[^\\pC]+$\320\001\001'
  _SCHEMAMETADATA.fields_by_name['description']._options = None
  _SCHEMAMETADATA.fields_by_name['description']._serialized_options = b'\372B\005r\003\030\210\''
  _SCHEMAMETADATA.fields_by_name['create_time']._options = None
  _SCHEMAMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SCHEMAMETADATA.fields_by_name['icon_uri']._options = None
  _SCHEMAMETADATA.fields_by_name['icon_uri']._serialized_options = b'\372B\022r\020:\010https://\320\001\001\210\001\001'
  _EVENTCONTRACTREF.fields_by_name['handle']._options = None
  _EVENTCONTRACTREF.fields_by_name['handle']._serialized_options = b'\372B\004r\002\020\004'
  _EVENTCONTRACTREF.fields_by_name['name']._options = None
  _EVENTCONTRACTREF.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _EVENTCONTRACTREF.fields_by_name['version']._options = None
  _EVENTCONTRACTREF.fields_by_name['version']._serialized_options = b'\372B\023r\0212\017^\\d+\\.\\d+\\.\\d+$'
  _EVENTCONTRACT_PIIFIELDSENTRY._options = None
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _EVENTCONTRACT.fields_by_name['ref']._options = None
  _EVENTCONTRACT.fields_by_name['ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['state']._options = None
  _EVENTCONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _EVENTCONTRACT.fields_by_name['schema_ref']._options = None
  _EVENTCONTRACT.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['key_field']._options = None
  _EVENTCONTRACT.fields_by_name['key_field']._serialized_options = b'\340A\002'
  _EVENTCONTRACTMETADATA.fields_by_name['title']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['description']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _LABEL.fields_by_name['key']._options = None
  _LABEL.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _VALIDATION.fields_by_name['field']._options = None
  _VALIDATION.fields_by_name['field']._serialized_options = b'\372B\004r\002\020\001'
  _VALIDATION.fields_by_name['type']._options = None
  _VALIDATION.fields_by_name['type']._serialized_options = b'\372B\tr\007R\005regex'
  _VALIDATION.fields_by_name['value']._options = None
  _VALIDATION.fields_by_name['value']._serialized_options = b'\372B\004r\002\020\001'
  _STREAMTREE.fields_by_name['stream']._options = None
  _STREAMTREE.fields_by_name['stream']._serialized_options = b'\340A\002'
  _SINKTREE.fields_by_name['sink']._options = None
  _SINKTREE.fields_by_name['sink']._serialized_options = b'\340A\002'
  _SINKTREE._options = None
  _SINKTREE._serialized_options = b'\030\001'
  _BATCHJOB.fields_by_name['ref']._options = None
  _BATCHJOB.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['states']._options = None
  _BATCHJOB.fields_by_name['states']._serialized_options = b'\340A\003'
  _BATCHJOB.fields_by_name['source_data']._options = None
  _BATCHJOB.fields_by_name['source_data']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['consent']._options = None
  _BATCHJOB.fields_by_name['consent']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['encryption']._options = None
  _BATCHJOB.fields_by_name['encryption']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['event_contract_ref']._options = None
  _BATCHJOB.fields_by_name['event_contract_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['encrypted_data']._options = None
  _BATCHJOB.fields_by_name['encrypted_data']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['encryption_keys_data']._options = None
  _BATCHJOB.fields_by_name['encryption_keys_data']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BATCHJOB.fields_by_name['policy_id']._options = None
  _BATCHJOB.fields_by_name['policy_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _BATCHJOBWRAPPER.oneofs_by_name['job']._options = None
  _BATCHJOBWRAPPER.oneofs_by_name['job']._serialized_options = b'\370B\001'
  _EXTENDEDBATCHJOB.fields_by_name['batch_job']._options = None
  _EXTENDEDBATCHJOB.fields_by_name['batch_job']._serialized_options = b'\030\001'
  _BATCHJOBREF.fields_by_name['billing_id']._options = None
  _BATCHJOBREF.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _BATCHJOBREF.fields_by_name['id']._options = None
  _BATCHJOBREF.fields_by_name['id']._serialized_options = b'\340A\003'
  _BATCHJOBREF.fields_by_name['project_id']._options = None
  _BATCHJOBREF.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _BATCHJOBSTATE.fields_by_name['state_time']._options = None
  _BATCHJOBSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['state']._options = None
  _BATCHJOBSTATE.fields_by_name['state']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['message']._options = None
  _BATCHJOBSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._serialized_options = b'\372B7r5\030\204\0072\t^.+[^\\/]$Z\001.Z\002..\272\001\032.well-known/acme-challenge\320\001\001'
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._serialized_options = b'\372B\020r\0162\t^[^\\pC]+$\320\001\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._options = None
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._serialized_options = b'\340A\001'
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._options = None
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._serialized_options = b'\340A\001'
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._options = None
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._options = None
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TIMESTAMPCONFIG.fields_by_name['field']._options = None
  _TIMESTAMPCONFIG.fields_by_name['field']._serialized_options = b'\372B\034r\032\020\004\03022\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _TIMESTAMPCONFIG.fields_by_name['format']._options = None
  _TIMESTAMPCONFIG.fields_by_name['format']._serialized_options = b'\372B\004r\002\020\001'
  _ENCRYPTEDDATA.fields_by_name['target']._options = None
  _ENCRYPTEDDATA.fields_by_name['target']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._options = None
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DERIVEDDATA.fields_by_name['target']._options = None
  _DERIVEDDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['ref']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['states']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['states']._serialized_options = b'\340A\003'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['source_data']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['source_data']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['target_data']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['target_data']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['data_contract_ref']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['data_contract_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['aggregation_config']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['aggregation_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _MICROAGGREGATIONCONFIG.fields_by_name['minimum_k_anonymity']._options = None
  _MICROAGGREGATIONCONFIG.fields_by_name['minimum_k_anonymity']._serialized_options = b'\372B\004\032\002(\002'
  _DATACONTRACTREF.fields_by_name['handle']._options = None
  _DATACONTRACTREF.fields_by_name['handle']._serialized_options = b'\340A\002\372B\004r\002\020\004'
  _DATACONTRACTREF.fields_by_name['name']._options = None
  _DATACONTRACTREF.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _DATACONTRACTREF.fields_by_name['version']._options = None
  _DATACONTRACTREF.fields_by_name['version']._serialized_options = b'\340A\002\372B\023r\0212\017^\\d+\\.\\d+\\.\\d+$'
  _DATACONTRACT_PIIFIELDSENTRY._options = None
  _DATACONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _DATACONTRACT.fields_by_name['id']._options = None
  _DATACONTRACT.fields_by_name['id']._serialized_options = b'\340A\003'
  _DATACONTRACT.fields_by_name['ref']._options = None
  _DATACONTRACT.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATACONTRACT.fields_by_name['state']._options = None
  _DATACONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _DATACONTRACT.fields_by_name['key_field']._options = None
  _DATACONTRACT.fields_by_name['key_field']._serialized_options = b'\372B\004r\002\020\001'
  _DATACONTRACT.fields_by_name['pii_fields']._options = None
  _DATACONTRACT.fields_by_name['pii_fields']._serialized_options = b'\030\001'
  _DATACONTRACT.fields_by_name['schema']._options = None
  _DATACONTRACT.fields_by_name['schema']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DATACONTRACT.fields_by_name['project_id']._options = None
  _DATACONTRACT.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_pii']._options = None
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_pii']._serialized_options = b'\340A\002'
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_quasi_id']._options = None
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_quasi_id']._serialized_options = b'\340A\002'
  _FIELDMETADATA_NULLHANDLINGCONFIG.fields_by_name['type']._options = None
  _FIELDMETADATA_NULLHANDLINGCONFIG.fields_by_name['type']._serialized_options = b'\340A\002'
  _DATACONTRACTMETADATA.fields_by_name['title']._options = None
  _DATACONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\372B\037r\035\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$\320\001\001'
  _DATACONTRACTMETADATA.fields_by_name['create_time']._options = None
  _DATACONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _PROJECT.fields_by_name['id']._options = None
  _PROJECT.fields_by_name['id']._serialized_options = b'\340A\003'
  _PROJECT.fields_by_name['name']._options = None
  _PROJECT.fields_by_name['name']._serialized_options = b'\372B\034r\032\020\002\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _PROJECT.fields_by_name['description']._options = None
  _PROJECT.fields_by_name['description']._serialized_options = b'\372B\005r\003\030\210\''
  _PROJECT.fields_by_name['organization_id']._options = None
  _PROJECT.fields_by_name['organization_id']._serialized_options = b'\340A\003'
  _PROJECT.fields_by_name['state']._options = None
  _PROJECT.fields_by_name['state']._serialized_options = b'\340A\003'
  _USER.fields_by_name['email']._options = None
  _USER.fields_by_name['email']._serialized_options = b'\372B\007r\005\320\001\001`\001'
  _USER.fields_by_name['first_name']._options = None
  _USER.fields_by_name['first_name']._serialized_options = b'\372B\034r\032\020\002\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _USER.fields_by_name['last_name']._options = None
  _USER.fields_by_name['last_name']._serialized_options = b'\372B\034r\032\020\002\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _PURPOSEMAPPING.fields_by_name['level']._options = None
  _PURPOSEMAPPING.fields_by_name['level']._serialized_options = b'\372B\004\032\002(\000'
  _PURPOSEMAPPING.fields_by_name['purpose']._options = None
  _PURPOSEMAPPING.fields_by_name['purpose']._serialized_options = b'\372B\006r\004\020\002\030d'
  _PURPOSEMAPPING.fields_by_name['description']._options = None
  _PURPOSEMAPPING.fields_by_name['description']._serialized_options = b'\372B\007r\005\020\002\320\001\001'
  _USERROLE._serialized_start=18745
  _USERROLE._serialized_end=18838
  _BATCHJOBSTATETYPE._serialized_start=18841
  _BATCHJOBSTATETYPE._serialized_end=18982
  _CONSENTLEVELTYPE._serialized_start=18984
  _CONSENTLEVELTYPE._serialized_end=19068
  _SINKTYPE._serialized_start=19070
  _SINKTYPE._serialized_end=19131
  _AUTHMECHANISM._serialized_start=19133
  _AUTHMECHANISM._serialized_end=19210
  _SCHEMATYPE._serialized_start=19212
  _SCHEMATYPE._serialized_end=19279
  _SIMPLESCHEMANODETYPE._serialized_start=19282
  _SIMPLESCHEMANODETYPE._serialized_end=19414
  _FILTERPUBLICPRIVATE._serialized_start=19416
  _FILTERPUBLICPRIVATE._serialized_end=19511
  _STATISTICALDATATYPE._serialized_start=19513
  _STATISTICALDATATYPE._serialized_end=19614
  _SUBSCRIPTIONPLAN._serialized_start=19617
  _SUBSCRIPTIONPLAN._serialized_end=19763
  _STREAM._serialized_start=230
  _STREAM._serialized_end=913
  _EXTENDEDSTREAM._serialized_start=916
  _EXTENDEDSTREAM._serialized_end=1086
  _EXTENDEDSTREAMGROUP._serialized_start=1089
  _EXTENDEDSTREAMGROUP._serialized_end=1283
  _MASKEDFIELDS._serialized_start=1286
  _MASKEDFIELDS._serialized_end=1685
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_start=1487
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_end=1606
  _MASKEDFIELDS_PATTERNLIST._serialized_start=1608
  _MASKEDFIELDS_PATTERNLIST._serialized_end=1685
  _LIMITS._serialized_start=1687
  _LIMITS._serialized_end=1769
  _KEYSTREAM._serialized_start=1772
  _KEYSTREAM._serialized_end=1918
  _STREAMREF._serialized_start=1921
  _STREAMREF._serialized_end=2075
  _KEYSTREAMREF._serialized_start=2078
  _KEYSTREAMREF._serialized_end=2235
  _CREDENTIALS._serialized_start=2238
  _CREDENTIALS._serialized_end=2399
  _SINK._serialized_start=2402
  _SINK._serialized_end=2625
  _SINKREF._serialized_start=2627
  _SINKREF._serialized_end=2701
  _BUCKETCONFIG._serialized_start=2704
  _BUCKETCONFIG._serialized_end=2835
  _DATACONNECTOR._serialized_start=2838
  _DATACONNECTOR._serialized_end=3427
  _DATACONNECTORREF._serialized_start=3430
  _DATACONNECTORREF._serialized_end=3588
  _DATACONNECTORDEPENDENTENTITIES._serialized_start=3591
  _DATACONNECTORDEPENDENTENTITIES._serialized_end=3898
  _AWSS3BUCKETLOCATION._serialized_start=3901
  _AWSS3BUCKETLOCATION._serialized_end=4059
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_start=4061
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_end=4180
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_start=4183
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_end=4449
  _AZURECLIENTSECRETCREDENTIAL._serialized_start=4452
  _AZURECLIENTSECRETCREDENTIAL._serialized_end=4603
  _DATATYPE._serialized_start=4605
  _DATATYPE._serialized_end=4693
  _CSVCONFIG._serialized_start=4695
  _CSVCONFIG._serialized_end=4732
  _BATCHEXPORTER._serialized_start=4735
  _BATCHEXPORTER._serialized_end=5385
  _EXTENDEDBATCHEXPORTER._serialized_start=5388
  _EXTENDEDBATCHEXPORTER._serialized_end=5540
  _BATCHEXPORTERREF._serialized_start=5543
  _BATCHEXPORTERREF._serialized_end=5704
  _KAFKACLUSTER._serialized_start=5707
  _KAFKACLUSTER._serialized_end=5957
  _KAFKACLUSTERREF._serialized_start=5960
  _KAFKACLUSTERREF._serialized_end=6105
  _KAFKAEXPORTER._serialized_start=6108
  _KAFKAEXPORTER._serialized_end=6415
  _KAFKAEXPORTERREF._serialized_start=6418
  _KAFKAEXPORTERREF._serialized_end=6564
  _KAFKAEXPORTERTARGET._serialized_start=6567
  _KAFKAEXPORTERTARGET._serialized_end=6827
  _KAFKAUSER._serialized_start=6830
  _KAFKAUSER._serialized_end=7152
  _KAFKAUSERREF._serialized_start=7154
  _KAFKAUSERREF._serialized_end=7264
  _CONSENTLEVELS._serialized_start=7266
  _CONSENTLEVELS._serialized_end=7320
  _CONSENTLEVELMAPPING._serialized_start=7323
  _CONSENTLEVELMAPPING._serialized_end=7478
  _CONSENTLEVELMAPPINGREF._serialized_start=7481
  _CONSENTLEVELMAPPINGREF._serialized_end=7622
  _POLICY._serialized_start=7625
  _POLICY._serialized_end=8003
  _POLICY_STATE._serialized_start=7918
  _POLICY_STATE._serialized_end=8003
  _WINDOWEDEVENTCOUNT._serialized_start=8006
  _WINDOWEDEVENTCOUNT._serialized_end=8188
  _SCHEMAREF._serialized_start=8191
  _SCHEMAREF._serialized_end=8366
  _SCHEMA._serialized_start=8369
  _SCHEMA._serialized_end=9228
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_start=8809
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_end=9128
  _SCHEMA_STATE._serialized_start=9130
  _SCHEMA_STATE._serialized_end=9228
  _SIMPLESCHEMANODE._serialized_start=9231
  _SIMPLESCHEMANODE._serialized_end=9586
  _SCHEMAMETADATA._serialized_start=9589
  _SCHEMAMETADATA._serialized_end=9930
  _EVENTCONTRACTREF._serialized_start=9933
  _EVENTCONTRACTREF._serialized_end=10087
  _EVENTCONTRACT._serialized_start=10090
  _EVENTCONTRACT._serialized_end=10860
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_start=10700
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_end=10760
  _EVENTCONTRACT_STATE._serialized_start=9130
  _EVENTCONTRACT_STATE._serialized_end=9228
  _EVENTCONTRACTMETADATA._serialized_start=10863
  _EVENTCONTRACTMETADATA._serialized_end=11183
  _LABEL._serialized_start=11185
  _LABEL._serialized_end=11241
  _VALIDATION._serialized_start=11243
  _VALIDATION._serialized_end=11351
  _STREAMTREE._serialized_start=11354
  _STREAMTREE._serialized_end=11736
  _SINKTREE._serialized_start=11739
  _SINKTREE._serialized_end=11898
  _BATCHJOB._serialized_start=11901
  _BATCHJOB._serialized_end=12741
  _BATCHJOBWRAPPER._serialized_start=12744
  _BATCHJOBWRAPPER._serialized_end=12984
  _EXTENDEDBATCHJOB._serialized_start=12987
  _EXTENDEDBATCHJOB._serialized_end=13141
  _BATCHJOBREF._serialized_start=13143
  _BATCHJOBREF._serialized_end=13264
  _BATCHJOBSTATE._serialized_start=13267
  _BATCHJOBSTATE._serialized_end=13452
  _DATACONNECTORANDTYPE._serialized_start=13455
  _DATACONNECTORANDTYPE._serialized_end=13801
  _CONSENTCONFIG._serialized_start=13804
  _CONSENTCONFIG._serialized_end=13991
  _CONSENTLEVELEXTRACTOR._serialized_start=13994
  _CONSENTLEVELEXTRACTOR._serialized_end=14259
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_start=14151
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_end=14259
  _ENCRYPTIONCONFIG._serialized_start=14262
  _ENCRYPTIONCONFIG._serialized_end=14424
  _TIMESTAMPCONFIG._serialized_start=14427
  _TIMESTAMPCONFIG._serialized_end=14599
  _ENCRYPTEDDATA._serialized_start=14601
  _ENCRYPTEDDATA._serialized_end=14701
  _ENCRYPTIONKEYSDATA._serialized_start=14703
  _ENCRYPTIONKEYSDATA._serialized_end=14808
  _DERIVEDDATA._serialized_start=14811
  _DERIVEDDATA._serialized_end=15116
  _MICROAGGREGATIONBATCHJOB._serialized_start=15119
  _MICROAGGREGATIONBATCHJOB._serialized_end=15686
  _MICROAGGREGATIONCONFIG._serialized_start=15689
  _MICROAGGREGATIONCONFIG._serialized_end=15817
  _DATACONTRACTREF._serialized_start=15820
  _DATACONTRACTREF._serialized_end=15979
  _DATACONTRACT._serialized_start=15982
  _DATACONTRACT._serialized_end=16884
  _DATACONTRACT_PIIFIELDSENTRY._serialized_start=10700
  _DATACONTRACT_PIIFIELDSENTRY._serialized_end=10760
  _DATACONTRACT_STATE._serialized_start=16786
  _DATACONTRACT_STATE._serialized_end=16884
  _FIELDMETADATA._serialized_start=16887
  _FIELDMETADATA._serialized_end=17752
  _FIELDMETADATA_PERSONALDATACONFIG._serialized_start=17303
  _FIELDMETADATA_PERSONALDATACONFIG._serialized_end=17495
  _FIELDMETADATA_NULLHANDLINGCONFIG._serialized_start=17498
  _FIELDMETADATA_NULLHANDLINGCONFIG._serialized_end=17752
  _FIELDMETADATA_NULLHANDLINGCONFIG_NULLHANDLINGTYPE._serialized_start=17662
  _FIELDMETADATA_NULLHANDLINGCONFIG_NULLHANDLINGTYPE._serialized_end=17752
  _DATACONTRACTMETADATA._serialized_start=17755
  _DATACONTRACTMETADATA._serialized_end=18053
  _PROJECT._serialized_start=18056
  _PROJECT._serialized_end=18371
  _PROJECT_STATE._serialized_start=18302
  _PROJECT_STATE._serialized_end=18371
  _USER._serialized_start=18374
  _USER._serialized_end=18610
  _PURPOSEMAPPING._serialized_start=18613
  _PURPOSEMAPPING._serialized_end=18743
# @@protoc_insertion_point(module_scope)
